@@ -44,14 +44,18 @@ BENCHMARK_PARAMS = pd.read_csv(S3_URL.format(
 PIPELINE_DIR = os.path.join(os.path.dirname(__file__), 'pipelines', 'verified')
 
 VERIFIED_PIPELINES = [
-    'arima', 'lstm_dynamic_threshold', 'azure', 'tadgan'
+    'arima', 'lstm_dynamic_threshold', 'azure', 'tadgan',
+    'aer', 'lstm_autoencoder', 'dense_autoencoder'
 ]
 
 VERIFIED_PIPELINES_GPU = {
     'arima': 'arima',
     'lstm_dynamic_threshold': 'lstm_dynamic_threshold_gpu',
     'azure': 'azure',
-    'tadgan': 'tadgan_gpu'
+    'tadgan': 'tadgan_without_dropout_gpu',
+    'aer': 'aer',
+    'lstm_autoencoder': 'lstm_autoencoder_gpu',
+    'dense_autoencoder': 'dense_autoencoder'
 }
 
 
@@ -121,7 +125,9 @@ def _sort_leaderboard(df, rank, metrics):
     df.reset_index(drop=False, inplace=True)
     df['rank'] += 1
 
-    return df.set_index('pipeline').reset_index()
+    pipeline_col = df.pop('pipeline')
+    df.insert(0, 'pipeline', pipeline_col)
+    return df
 
 
 def _evaluate_signal(pipeline, signal, hyperparameter, metrics,
