@@ -1,6 +1,6 @@
 """
 Time Series anomaly detection functions.
-Implementation inspired by the paper https://arxiv.org/pdf/1802.04431.pdf
+Some of the implementation is inspired by the paper https://arxiv.org/pdf/1802.04431.pdf
 """
 
 import numpy as np
@@ -8,37 +8,6 @@ import pandas as pd
 from scipy.optimize import fmin
 
 
-def regression_errors(y, y_hat, smoothing_window=0.01, smooth=True):
-    """Compute an array of absolute errors comparing predictions and expected output.
-
-    If smooth is True, apply EWMA to the resulting array of errors.
-
-    Args:
-        y (ndarray):
-            Ground truth.
-        y_hat (ndarray):
-            Predicted values.
-        smoothing_window (float):
-            Optional. Size of the smoothing window, expressed as a proportion of the total
-            length of y. If not given, 0.01 is used.
-        smooth (bool):
-            Optional. Indicates whether the returned errors should be smoothed with EWMA.
-            If not given, `True` is used.
-
-    Returns:
-        ndarray:
-            Array of errors.
-    """
-    errors = np.abs(y - y_hat)[:, 0]
-
-    if not smooth:
-        return errors
-
-    smoothing_window = int(smoothing_window * len(y))
-
-    return pd.Series(errors).ewm(span=smoothing_window).mean().values
-
-
 def deltas(errors, epsilon, mean, std):
     """Compute mean and std deltas.
 
@@ -218,7 +187,7 @@ def _find_sequences(errors, epsilon, anomaly_padding):
             * Maximum error value that was not considered an anomaly.
     """
     above = pd.Series(errors > epsilon)
-    index_above = np.argwhere(above)
+    index_above = np.argwhere(above.values)
 
     for idx in index_above.flatten():
         above[max(0, idx - anomaly_padding):min(idx + anomaly_padding + 1, len(above))] = True
@@ -510,7 +479,7 @@ def find_anomalies(errors, index, z_range=(0, 10), window_size=None, window_size
             inverted_window = mean - (window - mean)
             inverted_window_sequences = _find_window_sequences(inverted_window, z_range,
                                                                anomaly_padding, min_percent,
-                                                               window_start)
+                                                               window_start, fixed_threshold)
             sequences.extend(inverted_window_sequences)
 
         window_start = window_start + window_step_size
